package main

import (
	"strings"
	"time"
)

const (
	VM370_DATETIME_FMT = "15:04:05 MST Monday 01/02/06"
	VM370_TIME_FMT     = "15:04:05"
)

func mvs() *Log {
	log := New()
	log.add("STC18213 00000090 $HASP100 BPXAS ON STCINRDR")
	log.add("STC18213 00000090 $HASP373 BPXAS STARTED")
	log.add("STC18213 80000010 IEF403I BPXAS - STARTED - TIME=13.36.36 - ASID=001F - SC53")
	log.add("STC16316 00000291 IST663I IPS SRQ REQUEST FROM ISTAPNCP FAILED, SENSE=08570002")
	log.add(" 	111 00000291 IST664I REAL OLU=USIBMSC.S52TOS48 REAL DLU=USIBMSC.S48TO")
	log.add(" 	111 00000291 IST889I SID = ED0385CAAEEAAF28")
	log.add(" 	111 00000291 IST264I REQUIRED RESOURCE S48TOS52 NOT ACTIVE")
	log.add("  111 00000291 IST314I END")
	log.add("STC16352 00000291 IST663I IPS SRQ REQUEST FROM ISTAPNCP FAILED, SENSE=087D0001")
	log.add(" 	883 00000291 IST664I REAL OLU=USIBMSC.S52TOS48 ALIAS DLU=USIBMSC.S48TO")
	log.add(" 	883 00000291 IST889I SID = ED0385CAAEEAAF28")
	log.add(" 	883 00000291 IST314I END")
	log.add("STC28215 00000291 IST663I IPS SRQ REQUEST TO ISTAPNCP FAILED, SENSE=08570002 86")
	log.add(" 	864 00000291 IST664I REAL OLU=USIBMSC.S52TOS48 ALIAS DLU=USIBMSC.S48TO")
	log.add(" 	864 00000291 IST889I SID = ED0385CAAEEAAF28")
	log.add(" 	864 00000291 IST264I REQUIRED RESOURCE S48TOS52 NOT ACTIVE")
	log.add(" 	864 00000291 IST891I USIBMSC.SC48M GENERATED FAILURE NOTIFICATION")
	log.add(" 	864 00000291 IST314I END")
	return log
}

func vm370() *Log {
	log := New()
	log.add("VM/370 Community Edition Version  1 Release  1.1 05/02/21 12:49:03")
	log.add("")
	log.add("Now", strings.ToUpper(time.Now().Format(VM370_DATETIME_FMT)))
	log.add("")
	log.add("DMKCPI971I System is Uniprocessor generated")
	log.add("DMKCPI977I Free Trap Installed")
	log.add("")
	log.add("DMKUDR476I System Directory loaded from volume VM50-1")
	log.add("")
	log.add(time.Now().Format(VM370_TIME_FMT), "AUTO LOGON   ***   OPERATOR USERS = 001  BY  SYSTEM")
	log.add("")
	// Emit DMKCPI957I as a single multi-line message without delay, we're not emulating a 3215 - yet :-)
	log.addf("%s\n%s\n%s",
		"DMKCPI957I Storage size = 16384 K,   Nucleus = 336 K,",
		"           Dynamic Paging = 14788 K, Trace Table = 240 K,",
		"           Free Storage = 1020 K,    Virtual=Real = 00000 K")
	log.add("")
	log.add(time.Now().Format(VM370_TIME_FMT), "FILES: 001 RDR,  NO PRT,  NO PUN")
	log.add(time.Now().Format(VM370_TIME_FMT), "AUTO LOGON   ***   AUTOLOG1 USERS = 002  BY  OPERATOR")
	log.add("")
	log.add("DMKCPI966I Initialization complete")
	log.add("")
	log.add(time.Now().Format(VM370_TIME_FMT), "AUTO LOGON   ***   CPWATCH  USERS = 003  BY  AUTOLOG1")
	log.add(time.Now().Format(VM370_TIME_FMT), "RDR  00C DRAINED   SYSTEM")
	log.add(time.Now().Format(VM370_TIME_FMT), "PUN  00D DRAINED   SYSTEM   CLASS = P      SEP")
	log.add(time.Now().Format(VM370_TIME_FMT), "PRT  00E DRAINED   SYSTEM   CLASS = A      SEP")
	log.add(time.Now().Format(VM370_TIME_FMT), "PRT  00F DRAINED   SYSTEM   CLASS = A      SEP")
	log.add(time.Now().Format(VM370_TIME_FMT), "AUTO LOGON   ***   CMSBATCH USERS = 004  BY  AUTOLOG1")
	log.add(time.Now().Format(VM370_TIME_FMT), "AUTO LOGON   ***   WAKEUP   USERS = 005  BY  AUTOLOG1")
	log.add(time.Now().Format(VM370_TIME_FMT), "RDR  00C STARTED   SYSTEM")
	log.add(time.Now().Format(VM370_TIME_FMT), "PUN  00D STARTED   SYSTEM   CLASS = P      SEP")
	log.add(time.Now().Format(VM370_TIME_FMT), "PRT  00E STARTED   SYSTEM   CLASS = A      SEP")
	log.add(time.Now().Format(VM370_TIME_FMT), "PRT  00F STARTED   SYSTEM   CLASS = A      SEP")
	log.add(time.Now().Format(VM370_TIME_FMT), " WNG FROM AUTOLOG1:  AUTOLOG1 DONE - LOGGING OFF")
	log.add(time.Now().Format(VM370_TIME_FMT), "USER DSC LOGOFF AS AUTOLOG1 USERS = 004")
	return log
}

func bootVax() *Log {
	log := New()
	log.add("	-DKA300")
	log.add("VAX/VMS Version V5.3     Major version id = 1 Minor version id = 0")
	log.add("")
	log.add("")
	log.add("  ***************************************************************")
	log.add("")
	log.add("  VAX/VMS V5.3")
	log.add("")
	log.add("  You have SUCCESSFULLY installed the VMS operating system.")
	log.add("")
	log.add("  The system is now executing the STARTUP procedure.  Please")
	log.add("  await the completion of STARTUP before logging into the")
	log.add("  system (approximately three minutes).")
	log.add("")
	log.add("  ***************************************************************")
	log.add("")
	log.add("")
	log.add("The VAX/VMS system is now executing the system startup procedure.")
	log.add("")
	log.add("%SET-I-NEWAUDSRV, identification of new audit server process is 00000107")
	log.add("%LICENSE-F-EMTLDB, license database contains no license records")
	log.add("%SYSGEN-W-OPENIN, error opening SYS$COMMON:[SYSEXE]ZSDRIVER.EXE; as input")
	log.add("%SYSGEN-E-FNF, file not found")
	log.add("%LICENSE-E-NOAUTH, DEC VAX-VMS use is not authorized on this node")
	log.add("-LICENSE-F-NOLICENSE, no license is active for this software product")
	log.add("-LICENSE-I-SYSMGR, please see your system manager")
	log.add("Startup processing continuing...")
	log.add("")
	log.addf("%%%%%%%%%%%%  OPCOM  %v  %%%%%%%%%%%%", time.Now())
	log.add("Operator _OPA0: has been enabled, username SYSTEM")
	log.add("")
	log.addf("%%%%%%%%%%%%  OPCOM  %v  %%%%%%%%%%%%", time.Now())
	log.add("Operator status for operator _OPA0:")
	log.add("CENTRAL, PRINTER, TAPES, DISKS, DEVICES, CARDS, NETWORK, CLUSTER, SECURITY,")
	log.add("LICENSE, OPER1, OPER2, OPER3, OPER4, OPER5, OPER6, OPER7, OPER8, OPER9, OPER10,")
	log.add("OPER11, OPER12")
	log.add("")
	log.addf("%%%%%%%%%%%%  OPCOM  %v  %%%%%%%%%%%%", time.Now())
	log.add("Logfile has been initialized by operator _OPA0:")
	log.add("Logfile is SYS$SYSROOT:[SYSMGR]OPERATOR.LOG;1")
	log.add("")
	log.addf("%%%%%%%%%%%%  OPCOM  %v  %%%%%%%%%%%%", time.Now())
	log.add("Operator status for operator SYS$SYSROOT:[SYSMGR]OPERATOR.LOG;1")
	log.add("CENTRAL, PRINTER, TAPES, DISKS, DEVICES, CARDS, NETWORK, CLUSTER, SECURITY,")
	log.add("LICENSE, OPER1, OPER2, OPER3, OPER4, OPER5, OPER6, OPER7, OPER8, OPER9, OPER10,")
	log.add("OPER11, OPER12")
	log.add("")
	log.add("")
	log.add("The VAX/VMS system is now executing the site-specific startup commands.")
	log.add("")
	log.add("%SET-I-INTSET, login interactive limit = 64, current interactive value = 0")
	log.add("28-APR-2016 21:14:01")
	log.addf("SYSTEM       job terminated at %v", time.Now())
	log.add("")
	log.add("Accounting information:")
	log.add("Buffered I/O count:         1042      Peak working set size:   673")
	log.add("Direct I/O count:            547      Peak page file size:    2874")
	log.add("Page faults:                5668      Mounted volumes:           0")
	log.add("Charged CPU time:     0 00:00:28.89   Elapsed time:     0 00:01:42.76")
	log.add("")
	log.add("      Welcome to VAX/VMS V5.3")
	return log
}
